<?php

namespace HosgeldinKonuAcici\Listener;

use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Manager as EntityManager;

class NewUserListener
{
    /**
     * XF:User entity'si postSave event'ine abone olunduğunda çalışacak metod.
     *
     * @param Entity $user Yeni kaydedilen kullanıcı entity'si.
     * @param bool $isInsert Yeni kayıt mı, güncelleme mi olduğu.
     */
    public static function userPostSave(Entity $user, $isInsert)
    {
        // Yalnızca yeni kayıtlar için işlem yapalım.
        if (!$isInsert)
        {
            return;
        }
        
        // Admin ayarlarını alıyoruz.
        $options = \XF::options();
        if (empty($options->HosgeldinKonuAcici_active))
        {
            // Eklenti kapalı ise hiçbir işlem yapılmaz.
            return;
        }
        
        // Ayarlardan gerekli veriler
        $titleTemplate   = $options->HosgeldinKonuAcici_title;
        $contentTemplate = $options->HosgeldinKonuAcici_content;
        $starterUserId   = $options->HosgeldinKonuAcici_starter_user_id;
        $forumId         = $options->HosgeldinKonuAcici_forum_id;
        // Kategori ID'si ayrı bir kullanım gerektiriyorsa; örneğin forum node içinde kategori bilgisi varsa ek veriler olarak eklenebilir.
        $categoryId      = $options->HosgeldinKonuAcici_category_id;
        
        // Placeholder: [YeniÜye] metnini yeni kullanıcının kullanıcı adıyla değiştirelim.
        $finalTitle   = str_replace('[YeniÜye]', $user->username, $titleTemplate);
        $finalContent = str_replace('[YeniÜye]', $user->username, $contentTemplate);
        
        // Konuyu açacak olan üyenin entity'sini yükleyelim.
        $starterUser = \XF::em()->find('XF:User', $starterUserId);
        if (!$starterUser)
        {
            return;
        }
        
        // Konunun açılacağı forum node'unu yükleyelim.
        $node = \XF::em()->find('XF:Node', $forumId);
        if (!$node)
        {
            return;
        }
        
        // Thread (konu) oluşturma servisini başlatıyoruz.
        /** @var \XF\Service\Thread\Creator $threadCreator */
        $threadCreator = \XF::app()->service('XF:Thread\Creator', $starterUser, $node);
        $threadCreator->setDiscussionState('visible');
        $threadCreator->setTitle($finalTitle);
        $threadCreator->setMessage($finalContent);
        
        // Eğer kategori bilgisi eklemek gerekiyorsa, servise ek veriler geçilebilir. 
        // Örneğin: $threadCreator->setExtraData('category_id', $categoryId);
        
        // Konuyu oluşturuyoruz.
        try
        {
            $threadCreator->save();
        }
        catch (\Exception $e)
        {
            // Hata durumunda loglama veya hata yönetimi yapılabilir.
            \XF::logError($e->getMessage(), false, 'HosgeldinKonuAcici');
        }
    }
}
